# Changelog

<!--next-version-placeholder-->

## v0.2.0 (2022-06-23)


## v0.1.19 (2022-06-23)
### Fix
* Image created with wikilinks that don't end with image format ([`edd395a`](https://github.com/Mara-Li/mkdocs-ezlinked-plugin/commit/edd395afe84e2c56f275fe3543cc2f63ed3ea4f8))

## v0.1.18 (2022-03-28)


## v0.1.17 (2022-03-28)
### Fix
* Update to mkdocs 1.3.0 ([`86d8313`](https://github.com/Mara-Li/mkdocs-ezlinked-plugin/commit/86d83132d8c3967e2fa7f89df7647d5393695648))
* Update to mkdocs 1.3.0 ([`6529730`](https://github.com/Mara-Li/mkdocs-ezlinked-plugin/commit/652973032718f9f2f49c837461762d4c1a88fe8e))

## v0.1.16 (2022-03-23)


## v0.1.15 (2022-03-23)
### Fix
* **Wikilinks:** Removing slug in wiki seems to repear my links problem ([`9c3665c`](https://github.com/Mara-Li/mkdocs-ezlinks-plugin/commit/9c3665c6657f6956f06668bde131c4ee8320272f))
